#!/bin/bash
#
# Copyright (C) 2018 Purism SPC
#
# SPDX-License-Identifier: GPL-3.0+
#

usage() {
  echo "Usage : $1 "
  echo "    -h Display this help message."
  echo "    -T [ci|unstable] use the artifacts from this build for the image"
  echo "    -x extract the image for flashing"
  echo "    -k get the kernel binaries as well"
}

build_type=ci
pureos_board=devkit
extract=0
get_kernel=0

while getopts "xkhT:" opt; do
  case ${opt} in
    T)
      build_type=$OPTARG
      ;;
    x)
      extract=1
      ;;
    k)
      get_kernel=1
      ;;
    \?)
      echo "Invalid Option: -$OPTARG" 1>&2
      usage "$0"
      exit 0
      ;;
    h )
      usage "$0"
      exit 0
      ;;
  esac
done

[ ! -e files ] && mkdir files

base_url=https://storage.puri.sm/librem5/binaries/${build_type}/latest/

wget -N "${base_url}/${pureos_board}.img.xz" -P files/
#wget -N "${base_url}/${pureos_board}-test.img.xz" -P files/
wget -N https://arm01.puri.sm/job/Images/job/devkit-test_image_build/lastSuccessfulBuild/artifact/devkit-test.img.xz -P files/

if [ "${extract}" == 1 ] && 
        [ ! -e files/${pureos_board}.img ] ||
        [ files/${pureos_board}.img.xz -nt files/${pureos_board}.img ] ||
        [ files/${pureos_board}-test.img.xz -nt files/${pureos_board}-test.img ]; then
    xz -vfdk files/${pureos_board}.img.xz
    xz -vfdk files/${pureos_board}-test.img.xz
fi

wget -N "${base_url}/files/uboot-${pureos_board}-recovery/u-boot-${pureos_board}-recovery.imx" -P files/
wget -N "${base_url}/files/uboot-${pureos_board}/u-boot-${pureos_board}.imx" -P files/
wget -N "${base_url}/files/uboot-${pureos_board}/m4.bin" -P files/

if [ "${get_kernel}" == 1 ]; then
    wget -r -np -R "index.html*" -N https://arm01.puri.sm/job/Kernel_builds/job/Emcraft_Kernel_CI_build/lastSuccessfulBuild/artifact/files/*zip*/files.zip -nH --cut-dirs=8 -P files
    cd files
    unzip -oj files.zip
    gzip -f rsi_upgrade.tar
    gzip -f rsi_firmware.tar
fi

